==> subhajit_engg_tools-1.1.2.tar.gz: subhajit_engg_tools-1.1.2/README.md <==
# subhajit-engineering-tools 📦

[![PyPI version](https://badge.fury.io/py/subhajit-engineering-tools.svg)](https://badge.fury.io/py/subhajit-engineering-tools)
[![Build Status](https://travis-ci.com/subhajitss/subhajit-engineering-tools.svg?branch=main)](https://travis-ci.com/subhajitss/subhajit-engineering-tools)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

A Python package for **engineering works**, designed to make ETL easier and more efficient.

## Features 🚀

- **Feature 1**: Database Connectors.
- **Feature 2**: ETL Tools.
- **Feature 3**: Smarthome and Youtube data connectors.
- **Feature 4**: Yet to add. Got an idea? Most welcome to collaborate. Just raise a PR.

## Installation 📦

You can install the package directly from PyPI using pip:

```bash
pip install subhajit-engineering-tools
```

## Usage 🛠️
Example:
```python
from subhajit_engg_tools.connectors.postgres import Postgres
```

## Requirements 📋
This package requires:

Python 3.7 or higher.
Follow `requirements.txt` for other requirements

## Development 🛠️
To contribute or set up the project for development:

1. Clone the repository:
```bash
git clone https://github.com/subhajitsr/subhajit-engineering-tools
```
2. Navigate to the project folder:
```bash
cd subhajit-engineering-tools
```
3. Install the dependencies:
```bash
pip install -r requirements.txt
```

## Testing ✅
We use pytest for running tests. Run the following command to execute the tests:
```bash
pytest
```

## Contributing 🤝
Contributions are welcome! Please open an issue or submit a pull request for any bugs, improvements, or feature requests.

## Contact 📬
Author: Subhajit Maji

Email: mailto:subhajitsr@gmail.com

==> subhajit_engg_tools-1.1.3.tar.gz: subhajit_engg_tools-1.1.3/README.md <==
# subhajit-engineering-tools 📦

[![PyPI version](https://badge.fury.io/py/subhajit-engineering-tools.svg)](https://badge.fury.io/py/subhajit-engineering-tools)
[![Build Status](https://travis-ci.com/subhajitss/subhajit-engineering-tools.svg?branch=main)](https://travis-ci.com/subhajitss/subhajit-engineering-tools)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

A Python package for **engineering works**, designed to make ETL easier and more efficient.

## Features 🚀

- **Feature 1**: Database Connectors.
- **Feature 2**: ETL Tools.
- **Feature 3**: Smarthome and Youtube data connectors.
- **Feature 4**: Yet to add. Got an idea? Most welcome to collaborate. Just raise a PR.

## Installation 📦

You can install the package directly from PyPI using pip:

```bash
pip install subhajit_engg_tools
```

## Usage 🛠️
Example:
```python
from subhajit_engg_tools.connectors.postgres import Postgres
```

## Requirements 📋
This package requires:

Python 3.7 or higher.
Follow `requirements.txt` for other requirements

## Development 🛠️
To contribute or set up the project for development:

1. Clone the repository:
```bash
git clone https://github.com/subhajitsr/subhajit-engineering-tools
```
2. Navigate to the project folder:
```bash
cd subhajit-engineering-tools
```
3. Install the dependencies:
```bash
pip install -r requirements.txt
```

## Testing ✅
We use pytest for running tests. Run the following command to execute the tests:
```bash
pytest
```

## Contributing 🤝
Contributions are welcome! Please open an issue or submit a pull request for any bugs, improvements, or feature requests.

## Contact 📬
Author: Subhajit Maji

Email: mailto:subhajitsr@gmail.com
